@@ -26,7 +26,6 @@ current_args = {}
 class Call:
     op: str
     params: dict
-    case_change: bool
 
 
 app_host = os.environ.get("APP_HOST", "localhost:3000")
@@ -112,27 +111,17 @@ def live_user_visible_arg_map(dict: Dict[Any, Any]):
 
 
 arg_map: Dict[str, Callable[[Dict[Any, Any]], Dict[Any, Any]]] = {
-    "messageDirect": message_arg_map,
-    "messageAdd": message_arg_map,
-    "conversationStart": conversation_arg_map,
-    "conversationUserAdd": conversation_arg_map,
-    "userVisible": live_user_visible_arg_map,
+    "message_moderate": message_arg_map,
+    "message_direct": message_arg_map,
+    "message_add": message_arg_map,
+    "conversation_start": conversation_arg_map,
+    "conversation_user_add": conversation_user_arg_map,
+    "conversation_user_show": conversation_user_arg_map,
+    "conversation_update": conversation_arg_map,
+    "user_visible": live_user_visible_arg_map,
 }
 
 
-def convert_keys_to_snake_case(data):
-    if isinstance(data, dict):
-        new_data = {}
-        for key, value in data.items():
-            new_key = re.sub(r"(?<!^)(?=[A-Z])", "_", key).lower()
-            new_data[new_key] = convert_keys_to_snake_case(value)
-        return new_data
-    elif isinstance(data, list):
-        return [convert_keys_to_snake_case(item) for item in data]
-    else:
-        return data
-
-
 def convert_to_dict(data):
     if is_dataclass(data):
         return convert_to_dict(asdict(data))  # type: ignore
@@ -146,30 +135,6 @@ def convert_to_dict(data):
         return data
 
 
-def to_camel_case(snake_str):
-    return "".join(x.capitalize() for x in snake_str.lower().split("_"))
-
-
-def to_lower_camel_case(snake_str):
-    # We capitalize the first letter of each component except the first one
-    # with the 'capitalize' method and join them together.
-    camel_string = to_camel_case(snake_str)
-    return snake_str[0].lower() + camel_string[1:]
-
-
-def convert_keys_to_camel_case(data):
-    if isinstance(data, dict):
-        new_data = {}
-        for key, value in data.items():
-            new_key = to_lower_camel_case(key)
-            new_data[new_key] = convert_keys_to_camel_case(value)
-        return new_data
-    elif isinstance(data, list):
-        return [convert_keys_to_camel_case(item) for item in data]
-    else:
-        return data
-
-
 def start():
     """
     Start your bot, this runs the event loop so your bot can receive calls
@@ -184,7 +149,7 @@ def start():
     calls = pending_calls
     pending_calls = []
     for call in calls:
-        call_no_return(call.op, call.params, call.case_change)
+        call_no_return(call.op, call.params)
 
     message_read_loop()
 
@@ -192,7 +157,7 @@ def start():
 def run_call(message: str):
     global current_args
 
-    msg = typing.cast(Any, convert_keys_to_snake_case(json.loads(message)))
+    msg = typing.cast(Any, json.loads(message))
     log("[BOT] message", msg)
     funcName = msg.get("func")
     funcParams = msg.get("params")
@@ -219,7 +184,7 @@ def start_nonblocking():
     calls = pending_calls
     pending_calls = []
     for call in calls:
-        call_no_return(call.op, call.params, call.case_change)
+        call_no_return(call.op, call.params)
 
     thread = threading.Thread(target=message_read_loop)
     thread.start()
@@ -233,7 +198,7 @@ def message_read_loop():
             run_call(message)
 
 
-def call_return(op: str, params: dict, case_change: bool = True) -> Any:
+def call_return(op: str, params: dict) -> Any:
     if not started:
         raise Exception(
             "You cannot call bot functions that require a return value until after start()"
@@ -242,16 +207,15 @@ def call_return(op: str, params: dict, case_change: bool = True) -> Any:
     converted = convert_to_dict(params)
     # print("[BOT] client socket send", op, bot_context, converted)
     result = sio.call(
-        "call",
-        {
+        event="call",
+        data={
             "op": op,
             "input": {
                 "context": bot_context,
-                "params": (
-                    convert_keys_to_camel_case(converted) if case_change else converted
-                ),
+                "params": converted,
             },
         },
+        timeout=300,
     )
 
     if result is None:
@@ -261,31 +225,26 @@ def call_return(op: str, params: dict, case_change: bool = True) -> Any:
     if error is not None:
         raise Exception(error)
 
-    return (
-        convert_keys_to_snake_case(result.get("data"))
-        if case_change
-        else result.get("data")
-    )
+    return result.get("data")
 
 
-def call_no_return(op: str, params: Any, case_change: bool = True) -> None:
+def call_no_return(op: str, params: Any) -> None:
     if not started:
-        pending_calls.append(Call(op=op, params=params, case_change=case_change))
+        pending_calls.append(Call(op=op, params=params))
         return
 
     converted = convert_to_dict(params)
     # print("[BOT] client socket send", op, bot_context, converted)
     result = sio.call(
-        "call",
-        {
+        event="call",
+        data={
             "op": op,
             "input": {
                 "context": bot_context,
-                "params": (
-                    convert_keys_to_camel_case(converted) if case_change else converted
-                ),
+                "params": converted,
             },
         },
+        timeout=300,
     )
 
     if result is None:
@@ -433,6 +392,19 @@ def message_send(
     )
 
 
+def message_continue(message: Message) -> None:
+    """
+    Continue a message to the active conversation, only used by moderator bots
+    """
+
+    print(current_args)
+
+    return call_no_return(
+        "botCodeMessageContinue",
+        {"message": message},
+    )
+
+
 def message_send_all(
     text: Optional[str] = None,
     image: Optional[Image] = None,
@@ -611,18 +583,17 @@ def query_files(
 
 
 def query_news(
-    query: str, created: Optional[int] = None, limit: Optional[int] = None
+    query: Optional[str] = None,
+    created: Optional[int] = None,
+    limit: Optional[int] = None,
+    categories: Optional[List[NewsCategory]] = None,
 ) -> List[NewsArticle]:
     """
     Get news based on semantic search using the query
     """
     result = call_return(
         "botCodeQueryNews",
-        {
-            "query": query,
-            "created": created,
-            "limit": limit,
-        },
+        {"query": query, "created": created, "limit": limit, "categories": categories},
     )
 
     return list(map(lambda m: NewsArticle(**m), result))
@@ -849,6 +820,7 @@ def file_create(
     lang: Optional[UserLang] = None,
     indexable: Optional[bool] = None,
     page: Optional[dict] = None,
+    tags: Optional[List[str]] = None,
 ) -> File:
     """
     Create file
@@ -865,6 +837,7 @@ def file_create(
                 "lang": lang,
                 "indexable": indexable,
                 "page": page,
+                "tags": tags,
             },
         )
     )
@@ -929,7 +902,7 @@ def markdown_create_image(file_id: str, image: Image) -> str:
 
 def data_set(**kwargs) -> SimpleNamespace:
     """
-    Set bot data
+    Set bot data for conversation
     """
     return SimpleNamespace(
         **call_return(
@@ -941,7 +914,7 @@ def data_set(**kwargs) -> SimpleNamespace:
 
 def data_get() -> SimpleNamespace:
     """
-    Get bot data
+    Get bot data for conversation
     """
     return SimpleNamespace(
         **call_return(
@@ -951,6 +924,35 @@ def data_get() -> SimpleNamespace:
     )
 
 
+def user_data_set(user_id: str, **kwargs) -> SimpleNamespace:
+    """
+    Set bot data for specified user
+    """
+    return SimpleNamespace(
+        **call_return(
+            "botCodeUserDataSet",
+            {
+                "user_id": user_id,
+                "data": kwargs,
+            },
+        )
+    )
+
+
+def user_data_get(user_id: str) -> SimpleNamespace:
+    """
+    Get bot data for specified user
+    """
+    return SimpleNamespace(
+        **call_return(
+            "botCodeUserDataGet",
+            {
+                "user_id": user_id,
+            },
+        )
+    )
+
+
 def web_page_get(session_id: str) -> WebPageData:
     """
     Get active web page, this only works when Ugly is being used a sidePanel in Chrome
@@ -975,7 +977,6 @@ def log(
             "type": "log",
             "args": args,
         },
-        case_change=False,
     )
 
 
@@ -991,7 +992,6 @@ def error(
             "type": "error",
             "args": args,
         },
-        case_change=False,
     )
 
 
