@@ -52,10 +52,14 @@ class ImageGenSize(StrEnum):
     """portrait_4_3"""
     PORTRAIT_16_9 = "portrait_16_9"
     """portrait_16_9"""
+    PORTRAIT_21_9 = "portrait_21_9"
+    """portrait_21_9"""
     LANDSCAPE_4_3 = "landscape_4_3"
     """landscape_4_3"""
     LANDSCAPE_16_9 = "landscape_16_9"
     """landscape_16_9"""
+    LANDSCAPE_21_9 = "landscape_21_9"
+    """landscape_21_9"""
 
 
 class MessageVisibility(StrEnum):
@@ -150,6 +154,8 @@ class BotTag(StrEnum):
     """web"""
     NEWS = "news"
     """news"""
+    MODERATOR = "moderator"
+    """moderator"""
 
 
 class Timezone(StrEnum):
@@ -320,8 +326,6 @@ class ConversationType(StrEnum):
     """group"""
     BOT = "bot"
     """bot"""
-    FILE = "file"
-    """file"""
 
 
 class TextGenRole(StrEnum):
@@ -348,8 +352,6 @@ class TextGenModel(StrEnum):
     """together_meta_llama_3_405b"""
     TOGETHER_META_LLAMA_VISION_3_11B = "together_meta_llama_vision_3_11b"
     """together_meta_llama_vision_3_11b"""
-    TOGETHER_META_LLAMA_VISION_3_90B = "together_meta_llama_vision_3_90b"
-    """together_meta_llama_vision_3_90b"""
     TOGETHER_META_LLAMA4_400B = "together_meta_llama4_400b"
     """together_meta_llama4_400b"""
     TOGETHER_QWEN2_VISION_72B = "together_qwen2_vision_72b"
@@ -398,3 +400,24 @@ class TextGenModel(StrEnum):
     """openai_o1"""
     OPENAI_O1_MINI = "openai_o1_mini"
     """openai_o1_mini"""
+
+
+class NewsCategory(StrEnum):
+    FASHION = "fashion"
+    """fashion"""
+    TECH = "tech"
+    """tech"""
+    SPORTS = "sports"
+    """sports"""
+    FOOD = "food"
+    """food"""
+    MUSIC = "music"
+    """music"""
+    AUTO = "auto"
+    """auto"""
+    NEWS = "news"
+    """news"""
+    HOME = "home"
+    """home"""
+    PR = "pr"
+    """pr"""
