@@ -10,19 +10,6 @@ from .bot_enums import *
 
 funcs = {}
 
-name_map = {
-    "message_direct": "messageDirect",
-    "message_add": "messageAdd",
-    "bot_hourly": "botHourly",
-    "file_create": "fileCreate",
-    "conversation_hourly": "conversationHourly",
-    "conversation_start": "conversationStart",
-    "conversation_user_add": "conversationUserAdd",
-    "conversation_user_show": "conversationUserShow",
-    "user_visible": "userVisible",
-    "web_page_updated": "webPageUpdated",
-}
-
 
 def export(name: str):
     """
@@ -59,9 +46,7 @@ def export(name: str):
                 return func(**filtered_kwargs)
             return func(**kwargs)
 
-        mapped_name = name_map.get(name)
-
-        funcs[mapped_name if mapped_name is not None else name] = wrapper
+        funcs[name] = wrapper
 
         return func
 
@@ -95,6 +80,10 @@ class ImageMimeType(StrEnum):
 
 @dataclass
 class Image:
+    """
+    Image
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     type: ImageType
@@ -162,6 +151,10 @@ class ButtonType(StrEnum):
 
 @dataclass
 class Button:
+    """
+    Button
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     type: ButtonType
@@ -178,6 +171,10 @@ class Button:
 
 @dataclass
 class MenuItem:
+    """
+    MenuItem
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     func: str
@@ -189,6 +186,10 @@ class MenuItem:
 
 @dataclass
 class Message:
+    """
+    Message
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     id: str
@@ -209,6 +210,9 @@ class Message:
     file_ids: Optional[List[str]] = None
     context_file_id: Optional[str] = None
     parent_message_id: Optional[str] = None
+    cache_text_to_speech: Optional[bool] = None
+    transcribed: Optional[bool] = None
+    body_html: Optional[str] = None
 
 
 TextGenMessageContent = Union[str, Image]
@@ -216,6 +220,10 @@ TextGenMessageContent = Union[str, Image]
 
 @dataclass
 class TextGenMessage:
+    """
+    TextGenMessage
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     role: TextGenRole
@@ -224,6 +232,10 @@ class TextGenMessage:
 
 @dataclass
 class TextGenTool:
+    """
+    TextGenTool
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     name: str
@@ -233,6 +245,10 @@ class TextGenTool:
 
 @dataclass
 class Avatar:
+    """
+    Avatar
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     image: Image
@@ -241,6 +257,10 @@ class Avatar:
 
 @dataclass
 class User:
+    """
+    User
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     id: str
@@ -256,6 +276,10 @@ class User:
 
 @dataclass
 class Emotion:
+    """
+    Emotion
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     neutral: int
@@ -269,6 +293,10 @@ class Emotion:
 
 @dataclass
 class LiveUser:
+    """
+    LiveUser
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     id: str
@@ -278,6 +306,10 @@ class LiveUser:
 
 @dataclass
 class Bot:
+    """
+    Bot
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     id: str
@@ -288,6 +320,10 @@ class Bot:
 
 @dataclass
 class File:
+    """
+    File
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     id: str
@@ -300,20 +336,29 @@ class File:
     markdown: Optional[str] = None
     uri: Optional[str] = None
     page: Optional[dict] = None
+    tags: Optional[List[str]] = None
 
 
 @dataclass
 class Conversation:
+    """
+    Conversation
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     id: str
     type: ConversationType
     title: str
-    file_id: Optional[str] = None
+    context: Optional[str] = None
 
 
 @dataclass
 class NewsArticle:
+    """
+    NewsArticle
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     title: str
@@ -323,6 +368,10 @@ class NewsArticle:
 
 @dataclass
 class FileChunk:
+    """
+    FileChunk
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     file_id: str
@@ -331,6 +380,10 @@ class FileChunk:
 
 @dataclass
 class SearchArticle:
+    """
+    USearchArticlesSearchArticleer
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     title: str
@@ -348,6 +401,10 @@ class ConversationContentType(StrEnum):
 
 @dataclass
 class ConversationContent:
+    """
+    ConversationContent
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     type: ConversationContentType
@@ -358,6 +415,10 @@ class ConversationContent:
 
 @dataclass
 class WebPageData:
+    """
+    WebPageData
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     html: str
@@ -367,6 +428,10 @@ class WebPageData:
 
 @dataclass
 class KagiSearchItem:
+    """
+    KagiSearchItem
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     url: str
@@ -396,6 +461,10 @@ class KagiSearchItem:
 
 @dataclass
 class KagiSearchOutput:
+    """
+    KagiSearchOutput
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     items: List[KagiSearchItem]
@@ -414,6 +483,10 @@ class KagiSearchOutput:
 
 @dataclass
 class Padding:
+    """
+    Padding
+    """
+
     model_config = ConfigDict(extra="ignore")  # Ignore extra fields
 
     left: int
